@@ -2,7 +2,7 @@
    drvSWF.cpp : This file is part of pstoedit
    Skeleton for the implementation of new backends
 
-   Copyright (C) 1993 - 2005 Wolfgang Glunz, wglunz34_AT_pstoedit.net
+   Copyright (C) 1993 - 2006 Wolfgang Glunz, wglunz34_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -592,7 +592,7 @@ void drvSWF::show_image(const PSImage & imageinfo)
 // 
 // If neither USE_PNG is defined in ming_config.h nor we have access to util/png2dbl.c we cannot support images
 //
-void drvSWF::show_image(const PSImage & imageinfo) {
+void drvSWF::show_image(const PSImage & /* imageinfo */ ) {
 	errf << "no support for bitmaps - need to have access to util/png2dbl.c at compile time or at least ming version 0.3 which direct support of png (USE_PNG in ming/config.h)" << endl;
 }
 #endif
