@@ -2,7 +2,7 @@
    poptions.cpp : This file is part of pstoedit
    program option handling 
 
-   Copyright (C) 1993 - 2005 Wolfgang Glunz, wglunz34_AT_pstoedit.net
+   Copyright (C) 1993 - 2006 Wolfgang Glunz, wglunz34_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,12 +28,9 @@
 #include <miscutil.h>
 
 USESTD
-
 #define UNUSEDARG(p)
-
-
-bool IntValueExtractor::getvalue(const char *optname, const char *instring, unsigned int &currentarg,
-								 int &result)
+bool IntValueExtractor::getvalue(const char *optname, const char *instring,
+								 unsigned int &currentarg, int &result)
 {
 	if (instring) {
 		result = atoi(instring);
@@ -55,11 +52,11 @@ unsigned int IntValueExtractor::gettypeID()
 }
 
 
-bool DoubleValueExtractor::getvalue(const char *optname, const char *instring, unsigned int &currentarg,
-								   double &result)
+bool DoubleValueExtractor::getvalue(const char *optname, const char *instring,
+									unsigned int &currentarg, double &result)
 {
 	if (instring) {
-		result =  atof(instring);
+		result = atof(instring);
 		currentarg++;
 		return true;
 	} else {
@@ -79,8 +76,8 @@ unsigned int DoubleValueExtractor::gettypeID()
 
 
 
-bool CharacterValueExtractor::getvalue(const char *optname, const char *instring, unsigned int &currentarg,
-									   char &result)
+bool CharacterValueExtractor::getvalue(const char *optname, const char *instring,
+									   unsigned int &currentarg, char &result)
 {
 	if (instring) {
 		result = instring[0];
@@ -113,8 +110,8 @@ unsigned int BoolBaseExtractor::gettypeID()
 }
 
 bool BoolInvertingExtractor::getvalue(const char *UNUSEDARG(optname),
-									  const char *UNUSEDARG(instring), unsigned int &UNUSEDARG(currentarg),
-									  bool &result)
+									  const char *UNUSEDARG(instring),
+									  unsigned int &UNUSEDARG(currentarg), bool &result)
 {
 	result = !result;			// just invert
 	return true;
@@ -137,34 +134,37 @@ bool BoolTrueExtractor::getvalue(const char *UNUSEDARG(optname), const char *UNU
 }
 
 
-void ProgramOptions::showvalues(ostream & outstr, bool withdescription ) const
+void ProgramOptions::showvalues(ostream & outstr, bool withdescription) const
 {
 	for (unsigned int i = 0; i < optcount; i++) {
 		(void) outstr.width(20);
-		outstr << alloptions[i]->flag << "\t : " << alloptions[i]->gettypename() << "\t : " ;
-		if (withdescription) outstr	<< alloptions[i]->description << "\t : ";
-		(void)alloptions[i]->writevalue(outstr);
+		outstr << alloptions[i]->flag << "\t : " << alloptions[i]->gettypename() << "\t : ";
+		if (withdescription)
+			outstr << alloptions[i]->description << "\t : ";
+		(void) alloptions[i]->writevalue(outstr);
 		outstr << endl;
 	}
 }
 
-void OptionBase::toString(RSString& result) const  {
-		C_ostrstream tempstream;
-		(void)writevalue(tempstream);
-		tempstream << ends;
+void OptionBase::toString(RSString & result) const
+{
+	C_ostrstream tempstream;
+	(void) writevalue(tempstream);
+	tempstream << ends;
 #ifdef  USE_NEWSTRSTREAM
-		const string str = tempstream.str();
-		// no freeze / delete needed since ostringstream::str returns a string and not char*
-		result = str.data();
+	const string str = tempstream.str();
+	// no freeze / delete needed since ostringstream::str returns a string and not char*
+	result = str.data();
 #else
-		result = tempstream.str();
-		tempstream.rdbuf()->freeze(0);
+	result = tempstream.str();
+	tempstream.rdbuf()->freeze(0);
 #endif
 }
 
-unsigned int ProgramOptions::parseoptions(ostream & outstr, unsigned int argc, const char * const *argv)
+unsigned int ProgramOptions::parseoptions(ostream & outstr, unsigned int argc,
+										  const char *const *argv)
 {
-	unsigned int i = 1;					// argv[0] is not of interest
+	unsigned int i = 1;			// argv[0] is not of interest
 	//debug outstr << "parsing options: argc : " << argc << endl;
 	while (i < argc) {
 		bool found = false;
@@ -194,14 +194,20 @@ unsigned int ProgramOptions::parseoptions(ostream & outstr, unsigned int argc, c
 	return unhandledCounter;
 }
 
-static void TeXescapedOutput(ostream & outstr, const char * const st)
+static void TeXescapedOutput(ostream & outstr, const char *const st)
 {
-	const char * s = st;
+	const char *s = st;
 	while (s && *s) {
-		switch (*s ) {
-			case '[' : outstr << "\\Lbr"; break;
-			case ']' : outstr << "\\Rbr"; break;
-			default: outstr << *s; break;
+		switch (*s) {
+		case '[':
+			outstr << "\\Lbr";
+			break;
+		case ']':
+			outstr << "\\Rbr";
+			break;
+		default:
+			outstr << *s;
+			break;
 		}
 		s++;
 	}
@@ -212,41 +218,59 @@ void ProgramOptions::showhelp(ostream & outstr, bool forTeX, bool withdescriptio
 	if (optcount && forTeX && withdescription) {
 		outstr << "\\begin{description}" << endl;
 	}
-	const char * const terminator = withdescription ? "] " : " ";
+	const char *const terminator = withdescription ? "] " : " ";
 	for (unsigned int i = 0; i < optcount; i++) {
 		if (forTeX) {
-			if ( ((alloptions[i]->propsheet != 9999) && (sheet == -1)) ||
-					(alloptions[i]->propsheet == sheet))
-			{ // 9999 means hidden
-			if (withdescription) outstr << "\\item["  ;
-			if (alloptions[i]->gettypeID() == bool_ty) {
-				if (alloptions[i]->optional) outstr << "\\oOpt{"; else outstr << "\\Opt{";
-				TeXescapedOutput(outstr,alloptions[i]->flag);
-				outstr << "}" << terminator <<  endl;
-			} else {
-				if (alloptions[i]->optional) outstr << "\\oOptArg{"; else outstr << "\\OptArg{";
-				TeXescapedOutput(outstr,alloptions[i]->flag);
-				outstr << "}" ;
-				const char * aname = alloptions[i]->argname ? alloptions[i]->argname : "missing arg name";
-				outstr << "{~";
-				TeXescapedOutput(outstr,aname);
-				outstr << "}" << terminator<< endl;				
-			}
-			if (withdescription) {
-			const char * help = alloptions[i]->TeXhelp ? alloptions[i]->TeXhelp : alloptions[i]->description;
-			outstr << help << endl << endl;
-			}
+			if ((!hideFromDoku(*(alloptions[i])) && (sheet == -1))
+				// -1 means : show all sheets (except the hidden ones)
+				|| (alloptions[i]->propsheet == sheet)) {
+				if (withdescription)
+					outstr << "\\item[";
+				if (alloptions[i]->gettypeID() == bool_ty) {
+					if (alloptions[i]->optional)
+						outstr << "\\oOpt{";
+					else
+						outstr << "\\Opt{";
+					TeXescapedOutput(outstr, alloptions[i]->flag);
+					outstr << "}" << terminator << endl;
+				} else {
+					if (alloptions[i]->optional)
+						outstr << "\\oOptArg{";
+					else
+						outstr << "\\OptArg{";
+					TeXescapedOutput(outstr, alloptions[i]->flag);
+					outstr << "}";
+					const char *aname =
+						alloptions[i]->argname ? alloptions[i]->argname : "missing arg name";
+					outstr << "{~";
+					TeXescapedOutput(outstr, aname);
+					outstr << "}" << terminator << endl;
+				}
+				if (withdescription) {
+					const char *help =
+						alloptions[i]->TeXhelp ? alloptions[i]->TeXhelp : alloptions[i]->
+						description;
+					outstr << help << endl << endl;
+				}
 #if 0
-			(void) outstr.width(20) ; outstr << alloptions[i]->flag << "\t : " << alloptions[i]->gettypename() << "\t : " << alloptions[i]->description   ;
-			if (alloptions[i]->optional) outstr << "]";
+				(void) outstr.width(20);
+				outstr << alloptions[i]->flag << "\t : " << alloptions[i]->
+					gettypename() << "\t : " << alloptions[i]->description;
+				if (alloptions[i]->optional)
+					outstr << "]";
 #endif
-			if (withdescription) outstr << endl;
+				if (withdescription)
+					outstr << endl;
 			}
 
 		} else {
-			if (alloptions[i]->optional) outstr << "[";
-			(void) outstr.width(20) ; outstr << alloptions[i]->flag << "\t : " << alloptions[i]->gettypename() << "\t : " << alloptions[i]->description   ;
-			if (alloptions[i]->optional) outstr << "]";
+			if (alloptions[i]->optional)
+				outstr << "[";
+			(void) outstr.width(20);
+			outstr << alloptions[i]->flag << "\t : " << alloptions[i]->
+				gettypename() << "\t : " << alloptions[i]->description;
+			if (alloptions[i]->optional)
+				outstr << "]";
 			outstr << endl;
 		}
 	}
@@ -274,9 +298,9 @@ void ProgramOptions::dumpunhandled(ostream & outstr) const
 	}
 }
 
-void ProgramOptions::add(OptionBase * op, const char * const membername_p)
+void ProgramOptions::add(OptionBase * op, const char *const membername_p)
 {
-	alloptions[optcount]   = op;
+	alloptions[optcount] = op;
 	op->membername = membername_p;
 	alloptions[++optcount] = 0;
 }
